@@ -1,10 +1,11 @@
-__version__ = "1.1.0"
+__version__ = "1.2.1"
 
 from .typehint import (
     AnnotatedTypeHint,
     ClassTypeHint,
     ForwardRefTypeHint,
     LiteralTypeHint,
+    TupleTypeHint,
     TypeHint,
     TypeVarTypeHint,
     UnionTypeHint,
@@ -17,6 +18,7 @@ __all__ = [
     "ClassTypeHint",
     "ForwardRefTypeHint",
     "LiteralTypeHint",
+    "TupleTypeHint",
     "TypeHint",
     "TypeVarTypeHint",
     "UnionTypeHint",
