@@ -1,10 +1,12 @@
 import collections
 import inspect
 import sys
+import typing
 import warnings
 from types import FrameType, FunctionType, ModuleType
 from typing import Any, Callable, Dict, Generic, Optional, Set, Tuple, TypeVar, Union, get_type_hints as _get_type_hints
 
+import typing_extensions
 from typing_extensions import Protocol, TypeGuard
 
 IS_PYTHON_AT_LAST_3_6 = sys.version_info[:2] <= (3, 6)
@@ -188,6 +190,32 @@ def get_type_var_from_string_repr(type_var_repr: str) -> object:
     return type_var
 
 
+def get_subscriptable_type_hint_from_origin(origin: object, *, __cache: Dict[Any, Any] = {}) -> Any:
+    """Given any type, returns its corresponding subscriptable version. This
+    is the type itself in most cases (assuming it is a subclass of
+    :class:`typing.Generic`), but for special types such as :class:`list` or
+    :class:`collections.abc.Sequence`, it returns the respective special alias
+    from the :mod:`typing` module instead."""
+
+    if not __cache:
+        if sys.version_info[:2] <= (3, 6):
+            attr = "__extra__"
+        else:
+            attr = "__origin__"
+
+        def _populate(hint: Any) -> None:
+            origin = getattr(hint, attr, None)
+            if origin is not None:
+                __cache[origin] = hint
+
+        for value in vars(typing).values():
+            _populate(value)
+        for value in vars(typing_extensions).values():
+            _populate(value)
+
+    return __cache.get(origin, origin)
+
+
 # Generated in Python 3.8 with scripts/dump_type_vars.py.
 # We use this map to create TypeVars in get_type_hint_parameters() on the fly
 # for Python 3.9+ since they no longer come with this information embedded.
